@@ -20,8 +20,6 @@
 #include <termios.h>
 #include <unistd.h>
 
-#define PSPG_ESC_DELAY					2000
-
 #if defined(HAVE_INOTIFY)
 
 #include <sys/inotify.h>
@@ -37,6 +35,8 @@
 #include "inputs.h"
 #include "pspg.h"
 
+#define PSPG_NOTASSIGNED_CODE					0
+
 static char	pathname[MAXPATHLEN] = "";
 
 FILE   *f_tty = NULL;						/* ncurses input stream */
@@ -68,6 +68,9 @@ static bool saved_event_is_valid = false;
 static bool close_f_tty = false;
 static bool close_f_data = false;
 
+int		pspg_esc_delay;
+
+
 /*************************************
  * Events processing
  *
@@ -147,6 +150,13 @@ repeat:
 		return false;
 	}
 
+	/*
+	 * Workaround for issue #204. MacOS returns ERR when there are not
+	 * any other activity after ESC in ESCDELAY limit.
+	 */
+	if (nced->keycode == ERR && !first_event && errno == 0)
+		nced->keycode = PSPG_NOTASSIGNED_CODE;
+
 	nced->alt = !first_event;
 
 	return ok;
@@ -336,17 +346,32 @@ repeat_reading:
 					{
 						first_event = false;
 
-						/*
-						 * own implementation of escape delay. For fast escape - press
-						 * 2x escape.
-						 */
-						timeout = PSPG_ESC_DELAY;
-						goto repeat_reading;
+						if (pspg_esc_delay != 0)
+						{
+							if (pspg_esc_delay > 0)
+							{
+								timeout = pspg_esc_delay;
+								without_timeout = false;
+							}
+							else
+							{
+								timeout = -1;
+								without_timeout = true;
+							}
+
+							goto repeat_reading;
+						}
+						else
+						{
+							/* esc delay is not wanted */
+							nced->keycode = PSPG_ESC_CODE;
+							return PSPG_NCURSES_EVENT;
+						}
 					}
 
 					if (!first_event)
 					{
-						/* double escpae */
+						/* double escape */
 						if (nced->alt && nced->keycode == PSPG_NOTASSIGNED_CODE)
 							nced->keycode = PSPG_ESC_CODE;
 						else if (nced->keycode != KEY_MOUSE)
