@@ -89,6 +89,8 @@ static const char *bscommands[] = {
 	"sortd",
 	"rsort",
 	"dsort",
+	"desc",
+	"asc",
 	NULL
 };
 
@@ -400,7 +402,9 @@ pspg_complete(const char *text, int start, int end)
 									 IS_TOKEN(token, n, "sortd") ||
 									 IS_TOKEN(token, n, "dsort") ||
 									 IS_TOKEN(token, n, "rsort") ||
-									 IS_TOKEN(token, n, "rs"))
+									 IS_TOKEN(token, n, "rs") ||
+									 IS_TOKEN(token, n, "asc") ||
+									 IS_TOKEN(token, n, "desc"))
 							{
 								return rl_completion_matches(text, tablename_generator);
 							}
@@ -567,7 +571,7 @@ get_string(char *prompt,
 	tabcomplete_mode = _tabcomplete_mode;
 
 	wattron(prompt_window, prompt_window_input_attr);
-	mvwprintw(prompt_window, 0, 0, "");
+	wmove(prompt_window, 0, 0);
 	wclrtoeol(prompt_window);
 
 	curs_set(1);
@@ -645,7 +649,7 @@ get_string(char *prompt,
 					redraw_screen();
 
 					wattron(prompt_window, prompt_window_input_attr);
-					mvwprintw(prompt_window, 0, 0, "");
+					wmove(prompt_window, 0, 0);
 					wclrtoeol(prompt_window);
 
 					rl_forced_update_display();
