@@ -1,22 +1,5 @@
-#include <stdbool.h>
-
 #include "st_menu.h"
 
-#if defined HAVE_NCURSESW_CURSES_H
-#include <ncursesw/curses.h>
-#elif defined HAVE_NCURSESW_H
-#include <ncursesw.h>
-#elif defined HAVE_NCURSES_CURSES_H
-#include <ncurses/curses.h>
-#elif defined HAVE_NCURSES_H
-#include <ncurses.h>
-#elif defined HAVE_CURSES_H
-#include <curses.h>
-#else
-/* fallback */
-#include <ncurses/ncurses.h>
-#endif
-
 #include <string.h>
 
 /* 0..255 rgb based colors */
@@ -29,7 +12,6 @@ init_color_rgb_ff(short color, short r, short g, short b)
 			   (b / 255.0) * 1000.0);
 }
 
-
 /*
  * Set ligh colour
  */
@@ -61,29 +43,58 @@ slc(short id, short foreground, short background)
  * style it is number of already existing color pair.
  */
 int
-st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn)
+st_menu_load_style(ST_MENU_CONFIG *config, int style, int start_from_cpn,
+				   bool force8bit, bool force_ascii_art)
 {
-	return st_menu_load_style_rgb(config, style, start_from_cpn, NULL);
+	return st_menu_load_style_rgb(config,
+								  style,
+								  start_from_cpn,
+								  NULL,
+								  force8bit,
+								  force_ascii_art);
 }
 
 int
-st_menu_load_style_rgb(ST_MENU_CONFIG *config, int style, int start_from_cpn, int *start_from_rgb)
+st_menu_load_style_rgb(ST_MENU_CONFIG *config, int style, int start_from_cpn, int *start_from_rgb,
+					   bool force8bit, bool force_ascii_art)
 {
 	memset(config, 0, sizeof(ST_MENU_CONFIG));
 
 	config->submenu_tag = '>';
 	config->mark_tag = '*';
+	config->switch_tag_n1 = '?';
+	config->switch_tag_0 = '-';
+	config->switch_tag_1 = 'x';
+	config->scroll_up_tag = '^';
+	config->scroll_down_tag = 'v';
 	config->draw_box = true;
 	config->extern_accel_text_space = 2;
-	config->force_ascii_art = false;
+
+	config->force8bit = force8bit;
+	config->force_ascii_art = force_ascii_art;
 
 	config->submenu_offset_y = 0;
 	config->submenu_offset_x = 0;
 
 #if defined  HAVE_NCURSESW
 
-	if (!config->force8bit)
+	if (!config->force8bit && !config->force_ascii_art)
+	{
 		config->mark_tag = L'\x2714';
+/*
+		config->switch_tag_n1 = L'\x2680';
+		config->switch_tag_0 = L'\x2610';
+		config->switch_tag_1 = L'\x2611';
+*/
+
+		config->switch_tag_n1 = '.';
+		config->switch_tag_0 = ' ';
+		config->switch_tag_1 = L'\x2714';
+
+		config->scroll_up_tag = L'\x25b2';
+		config->scroll_down_tag = L'\x25bc';
+
+	}
 
 #endif
 
@@ -960,6 +971,87 @@ st_menu_load_style_rgb(ST_MENU_CONFIG *config, int style, int start_from_cpn, in
 
 			break;
 
+		case ST_MENU_STYLE_FLATWHITE:
+			if (start_from_rgb)
+			{
+				int		_start_from_rgb = *start_from_rgb;
+
+				*start_from_rgb += 7;
+
+				init_color_rgb_ff(_start_from_rgb + 0, 0xb9, 0xA9, 0x92); /* menu bg */
+				init_color_rgb_ff(_start_from_rgb + 1, 0x17, 0x17, 0x17); /* menu fg */
+				init_color_rgb_ff(_start_from_rgb + 2, 0x6a, 0x4d, 0xff); /* cursor bg */
+				init_color_rgb_ff(_start_from_rgb + 5, 0xff, 0xff, 0xff); /* cursor fg */
+				init_color_rgb_ff(_start_from_rgb + 3, 0x84, 0x7e, 0x76); /* shadow */
+				init_color_rgb_ff(_start_from_rgb + 4, 0x66, 0x66, 0x66); /* disabled */
+				init_color_rgb_ff(_start_from_rgb + 6, 0x00, 0x00, 0x00); /* accel */
+
+				config->menu_background_cpn = start_from_cpn;
+				init_pair(start_from_cpn++, _start_from_rgb + 1, _start_from_rgb + 0);
+				config->menu_background_attr = 0;
+
+				config->menu_unfocused_cpn = start_from_cpn;
+				init_pair(start_from_cpn++, _start_from_rgb + 1, _start_from_rgb + 0);
+				config->menu_unfocused_attr = 0;
+
+				config->menu_shadow_cpn = start_from_cpn;
+				config->menu_shadow_attr = 0;
+				init_pair(start_from_cpn++, COLOR_WHITE, _start_from_rgb + 3);
+
+				config->accelerator_cpn = start_from_cpn;
+				init_pair(start_from_cpn++, _start_from_rgb + 6, _start_from_rgb + 0);
+				config->accelerator_attr = A_UNDERLINE;
+
+				config->cursor_cpn = start_from_cpn;
+				init_pair(start_from_cpn++, _start_from_rgb + 5, _start_from_rgb + 2);
+				config->cursor_attr = 0;
+
+				config->cursor_accel_cpn = start_from_cpn;
+				init_pair(start_from_cpn++, _start_from_rgb + 5, _start_from_rgb + 2);
+				config->cursor_accel_attr = A_UNDERLINE ;
+
+				config->disabled_cpn = start_from_cpn;
+				init_pair(start_from_cpn, _start_from_rgb + 4, _start_from_rgb + 0);
+				config->disabled_attr = 0;
+			}
+			else
+			{
+				/* fallback */
+				config->menu_background_cpn = start_from_cpn;
+				config->menu_background_attr = islc(COLOR_BLACK, COLOR_WHITE);
+
+				config->menu_unfocused_cpn = start_from_cpn;
+				config->menu_unfocused_attr = islc(COLOR_BLACK, COLOR_WHITE);
+
+				config->menu_shadow_cpn = start_from_cpn;
+				config->menu_shadow_attr = 0;
+				init_pair(start_from_cpn++, COLOR_BLUE, COLOR_BLACK);
+
+				config->accelerator_cpn = start_from_cpn;
+				config->accelerator_attr = A_UNDERLINE | islc(COLOR_BLACK, COLOR_WHITE);
+
+				config->cursor_cpn = start_from_cpn;
+				config->cursor_attr = islc(COLOR_WHITE, COLOR_BLACK);
+
+				config->cursor_accel_cpn = start_from_cpn;
+				config->cursor_accel_attr = A_UNDERLINE | islc(COLOR_WHITE, COLOR_BLACK);
+
+				config->disabled_cpn = start_from_cpn;
+				config->disabled_attr = A_DIM | islc(COLOR_BLACK, COLOR_WHITE);
+			}
+
+			config->left_alligned_shortcuts = true;
+			config->wide_vborders = true;
+			config->wide_hborders = false;
+			config->extra_inner_space = false;
+
+			config->shortcut_space = 5;
+			config->text_space = 5;
+			config->init_text_space = 2;
+			config->menu_bar_menu_offset = 1;
+			config->shadow_width = 2;
+
+			break;
 	}
 
 	return start_from_cpn;
